@@ -11,6 +11,7 @@
 # under the License.
 
 import json
+
 import requests
 import yaml
 
@@ -54,7 +55,7 @@ class TestTriggerController(base.TestCase):
     def test_trigger_post(self):
 
         assembly_uuid, plan_uuid, trigger_uri = self._create_assembly()
-        #Using requests instead of self.client to test unauthenticated request
+        # Using requests instead of self.client to test unauthenticated request
         resp = requests.post(trigger_uri)
         self.assertEqual(resp.status_code, 202)
 
@@ -63,10 +64,8 @@ class TestTriggerController(base.TestCase):
     def _delete_assembly(self, assembly_uuid, plan_uuid):
         resp, body = self.client.delete('v1/assemblies/%s' % assembly_uuid)
         self.assertEqual(resp.status, 204)
-        if self.client.assembly_delete_done(assembly_uuid):
-            self._delete_plan(plan_uuid)
-        else:
-            self.fail("Assembly couldn't be deleted.")
+        self.assertTrue(self.client.assembly_delete_done(assembly_uuid))
+        self._delete_plan(plan_uuid)
 
     def _delete_plan(self, plan_uuid):
         resp, body = self.client.delete(
