@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -11,7 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import six
 from wsme.rest import json
 from wsme import types as wtypes
 
@@ -33,8 +33,8 @@ class BooleanType(wtypes.UserType):
 
     @staticmethod
     def validate(value):
-        if not isinstance(value, six.string_types):
-            value = six.text_type(value)
+        if not isinstance(value, basestring):
+            value = unicode(value)
 
         if value in TRUE_STRINGS:
             ret_val = True
