@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -10,7 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-ASSEM_URI_STR = '%s/camp/v1_1/assemblies/%s'
+# TODO(gilbert.pilz) - change this to point to CAMP-style assembly resource
+ASSEM_URI_STR = '%s/v1/assemblies/%s'
 
 ASSEMS_URI_STR = '%s/camp/v1_1/assemblies'
 
@@ -32,7 +35,7 @@ JSON_FORMAT_NAME_STR = 'JSON'
 PARAM_DEF_URI_STR = '%s/camp/v1_1/parameter_definition/%s'
 PARAM_DEFS_URI_STR = '%s/camp/v1_1/parameter_definitions/%s'
 
-PLAN_URI_STR = '%s/camp/v1_1/plans/%s'
+PLAN_URI_STR = '%s/v1/plans/%s'
 
 PLANS_URI_STR = '%s/camp/v1_1/plans'
 
