@@ -60,7 +60,7 @@ class Assembly(api_types.Base):
     def from_db_model(cls, m, host_url):
         obj = super(Assembly, cls).from_db_model(m, host_url)
         obj.plan_uri = '%s/v1/plans/%s' % (host_url, m.plan_uuid)
-        obj.trigger_uri = '%s/v1/public/triggers/%s' % (host_url, m.trigger_id)
+        obj.trigger_uri = '%s/v1/triggers/%s' % (host_url, m.trigger_id)
         return obj
 
     @classmethod
@@ -73,7 +73,7 @@ class Assembly(api_types.Base):
                    project_id='1dae5a09ef2b4d8cbf3594b0eb4f6b94',
                    user_id='55f41cf46df74320b9486a35f5d28a11',
                    description='A mysql database',
-                   trigger_uri='http://example.com/v1/public/triggers/1abc234',
+                   trigger_uri='http://example.com/v1/triggers/1abc234',
                    components=[],
                    operations=[],
                    sensors=[])
