@@ -14,6 +14,7 @@
 
 import uuid
 
+import six
 import wsme
 from wsme.rest import json as wjson
 from wsme import types as wtypes
@@ -51,7 +52,8 @@ class Artifact(wtypes.Base):
     artifact_type = wtypes.text
     "Type of artifact."
 
-    content = {wtypes.text: wtypes.text}
+    content = {wtypes.text: api_types.MultiType(wtypes.text,
+                                                six.types.BooleanType)}
     "Type specific content as a flat dict."
 
     language_pack = wtypes.text
@@ -63,6 +65,9 @@ class Artifact(wtypes.Base):
     unittest_cmd = wtypes.text
     "Optional unit test command for the artifact."
 
+    repo_token = wtypes.text
+    "The OAuth token to access repository"
+
     def __init__(self, **kwargs):
         if 'requirements' in kwargs:
             kwargs['requirements'] = [Requirement(**re)
@@ -88,6 +93,12 @@ class Plan(api_types.Base):
     services = [ServiceReference]
     """List of services needed by the plan."""
 
+    parameters = {wtypes.text: api_types.MultiType(wtypes.text,
+                                                   six.integer_types,
+                                                   six.types.BooleanType,
+                                                   six.types.FloatType)}
+    """User defined parameters"""
+
     def __init__(self, **kwargs):
         if 'artifacts' in kwargs:
             kwargs['artifacts'] = [Artifact(**art)
@@ -106,7 +117,8 @@ class Plan(api_types.Base):
                    artifacts=[{
                        'name': 'My-python-app',
                        'artifact_type': 'git_pull',
-                       'content': {'href': 'git://example.com/project.git'},
+                       'content': {'href': 'git://example.com/project.git',
+                                   'private': False},
                        'language_pack': str(uuid.uuid4()),
                        'requirements': [{
                            'requirement_type': 'git_pull',
@@ -131,4 +143,6 @@ class Plan(api_types.Base):
         if self.services is not wsme.Unset:
             base.update({'services': [wjson.tojson(ServiceReference, ref)
                                       for ref in self.services]})
+        if self.parameters is not wsme.Unset:
+            base.update({'parameters': self.parameters})
         return base
