@@ -17,8 +17,7 @@ from wsme import types as wtypes
 
 class Userlog(wtypes.Base):
 
-    resource_uuid = wtypes.text
-    resource_type = wtypes.text
+    assembly_uuid = wtypes.text
     created_at = wtypes.text
     location = wtypes.text
     strategy = wtypes.text
@@ -30,8 +29,7 @@ class Userlog(wtypes.Base):
     @classmethod
     def from_db_model(cls, m, host_url):
         return cls(
-            resource_uuid=m.resource_uuid,
-            resource_type=m.resource_type,
+            assembly_uuid=m.assembly_uuid,
             created_at=str(m.created_at),
             location=m.location,
             strategy=m.strategy,
