@@ -15,7 +15,7 @@
 import json
 import os
 
-from solum.api.controllers.camp.v1_1.datamodel import type_definitions as model
+from solum.api.controllers.camp.v1_1.datamodel import type_definitions
 from solum.api.handlers import handler
 
 
@@ -28,17 +28,21 @@ class TypeDefinitionHandler(handler.Handler):
         return os.path.normpath(os.path.join(os.path.dirname(__file__),
                                              '..', '..', '..', '..'))
 
+    @staticmethod
+    def as_typedef(dct):
+        if 'type' in dct and dct['type'] == 'type_definition':
+            return type_definitions.TypeDefinition.from_json(dct)
+        else:
+            return dct
+
     def _load_typedefs(self):
         typedef_dir_path = os.path.join(self.proj_dir, 'etc', 'solum', 'camp',
                                         'typeDefs')
-        for path in os.listdir(typedef_dir_path):
-            json_d = json.load(open(os.path.join(typedef_dir_path, path), 'r'))
-
-            # make sure this looks like a type_definition before we
-            # deserialize it
-            if 'type' in json_d and json_d['type'] == 'type_definition':
-                type_d = model.TypeDefinition.from_json(json_d)
-                TYPE_DEFS[type_d.uri] = type_d
+        files = os.listdir(typedef_dir_path)
+        for path in files:
+            f = open(os.path.join(typedef_dir_path, path), 'r')
+            type_d = json.load(f, object_hook=TypeDefinitionHandler.as_typedef)
+            TYPE_DEFS[type_d.uri] = type_d
 
     def __init__(self, context):
         super(TypeDefinitionHandler, self).__init__(context)
