@@ -27,6 +27,7 @@ from solum.openstack.common.gettextutils import _
 from solum.openstack.common import log as logging
 from solum.worker.handlers import noop as noop_handler
 from solum.worker.handlers import shell as shell_handler
+from solum.worker.handlers import shell_nobuild as shell_nobuild_handler
 
 LOG = logging.getLogger(__name__)
 
@@ -37,7 +38,7 @@ def main():
     solum.TLS.trace = trace_data.TraceData()
 
     LOG.info(_('Starting server in PID %s') % os.getpid())
-    LOG.debug(_("Configuration:"))
+    LOG.debug("Configuration:")
     cfg.CONF.log_opt_values(LOG, std_logging.DEBUG)
 
     cfg.CONF.import_opt('topic', 'solum.worker.config', group='worker')
@@ -47,6 +48,7 @@ def main():
     handlers = {
         'noop': noop_handler.Handler,
         'shell': shell_handler.Handler,
+        'shell_nobuild': shell_nobuild_handler.Handler,
     }
 
     endpoints = [
