@@ -12,13 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
+from oslo.config import cfg
 
-from solum.common import config
 from solum import objects
+from solum.openstack.common import log as logging
 
 
 def prepare_service(argv=[]):
     cfg.CONF(argv[1:], project='solum')
-    config.set_config_defaults()
+    logging.setup('solum')
     objects.load()
