@@ -29,5 +29,5 @@ class API(service.API):
     def deploy(self, assembly_id, image_id):
         self._cast('deploy', assembly_id=assembly_id, image_id=image_id)
 
-    def delete_heat_stack(self, assem_id):
-        self._cast('delete_heat_stack', assem_id=assem_id)
+    def destroy(self, assem_id):
+        self._cast('destroy', assem_id=assem_id)
