@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -20,7 +22,7 @@ from solum.tests import fakes
 
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
-@mock.patch('solum.api.handlers.camp.plan_handler.PlanHandler')
+@mock.patch('solum.api.handlers.plan_handler.PlanHandler')
 class TestPlans(base.BaseTestCase):
     def setUp(self):
         super(TestPlans, self).setUp()
@@ -31,7 +33,8 @@ class TestPlans(base.BaseTestCase):
         fake_plan = fakes.FakePlan()
         hand_get_all.return_value = [fake_plan]
 
-        resp = plans.PlansController().get()
+        cont = plans.PlansController()
+        resp = cont.get()
         self.assertIsNotNone(resp)
         self.assertEqual(200, resp_mock.status)
         self.assertIsNotNone(resp['result'].plan_links)
