@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -41,10 +43,22 @@ class TestExtensionHandler(base.BaseTestCase):
 
     def test_extension_update(self, mock_registry):
         data = {'name': 'new_name'}
+        db_obj = fakes.FakeExtension()
+        mock_registry.Extension.get_by_uuid.return_value = db_obj
         handler = extension.ExtensionHandler(self.ctx)
-        handler.update('test_id', data)
-        mock_registry.Extension.update_and_save.assert_called_once_with(
-            self.ctx, 'test_id', data)
+        res = handler.update('test_id', data)
+        self.assertEqual(db_obj.user_id, res.user_id)
+        self.assertEqual(db_obj.project_id, res.project_id)
+        self.assertEqual(db_obj.name, res.name)
+        self.assertEqual(db_obj.value, res.value)
+        self.assertEqual(db_obj.version, res.version)
+        self.assertEqual(db_obj.uuid, res.uuid)
+        self.assertEqual(db_obj.uri, res.uri)
+        self.assertEqual(db_obj.type, res.type)
+        db_obj.update.assert_called_once_with(data)
+        db_obj.save.assert_called_once_with(self.ctx)
+        mock_registry.Extension.get_by_uuid.assert_called_once_with(self.ctx,
+                                                                    'test_id')
 
     def test_extension_create(self, mock_registry):
         data = {'name': 'new_name',
