@@ -14,10 +14,13 @@
 
 import mock
 
+from solum.openstack.common import uuidutils
+
+
 fakeAuthTokenHeaders = {'X-User-Id': u'773a902f022949619b5c2f32cd89d419',
                         'X-Roles': u'admin, ResellerAdmin, _member_',
-                        'X-Project-Id': u'5588aebbcdc24e17a061595f80574376',
-                        'X-Project-Name': 'test',
+                        'X-Project-Id': u'fake_project_id',
+                        'X-Project-Name': 'fake_project_name',
                         'X-User-Name': 'test',
                         'X-Auth-Token': u'5588aebbcdc24e17a061595f80574376',
                         'X-Forwarded-For': u'10.10.10.10, 11.11.11.11',
@@ -64,7 +67,7 @@ class FakeService(mock.Mock):
         self.__tablename__ = 'service'
         self.__resource__ = 'services'
         self.user_id = 'fake user id'
-        self.project_id = 'fake project id'
+        self.project_id = 'fake_project_id'
         self.uuid = 'test_uuid'
         self.id = 8
         self.name = 'james'
@@ -99,7 +102,7 @@ class FakeSensor(mock.Mock):
         self.__tablename__ = 'sensor'
         self.__resource__ = 'sensors'
         self.user_id = 'test_user_id'
-        self.project_id = 'test_project_id'
+        self.project_id = 'fake_project_id'
         self.uuid = '54d54'
         self.id = 'test_id'
         self.name = 'test_name'
@@ -128,7 +131,7 @@ class FakeExtension(mock.Mock):
         self.__tablename__ = 'extension'
         self.__resource__ = 'extension'
         self.user_id = 'user_id'
-        self.project_id = 'test_id'
+        self.project_id = 'fake_project_id'
         self.uuid = '44du3dx'
         self.documentation = 'http://test_documentation.com'
         self.description = 'test_desc'
@@ -168,7 +171,7 @@ class FakeInfrastructureStack(mock.Mock):
         self.__tablename__ = 'build_farm'
         self.__resource__ = 'build_farms'
         self.user_id = 'user_id'
-        self.project_id = 'test_id'
+        self.project_id = 'fake_project_id'
         self.uuid = 'ceda0408-c93d-4772-abb2-18f65189d440'
         self.description = 'test_desc'
         self.id = 'test_id'
@@ -193,7 +196,7 @@ class FakeAssembly(mock.Mock):
         self.__tablename__ = 'assembly'
         self.__resource__ = 'assemblies'
         self.user_id = 'fake user id'
-        self.project_id = 'fake project id'
+        self.project_id = 'fake_project_id'
         self.plan_uuid = 'fake plan uuid'
         self.uuid = 'test_uuid'
         self.id = 8
@@ -219,7 +222,7 @@ class FakePipeline(mock.Mock):
         self.__tablename__ = 'pipeline'
         self.__resource__ = 'pipelines'
         self.user_id = 'fake user id'
-        self.project_id = 'fake project id'
+        self.project_id = 'fake_project_id'
         self.plan_uuid = 'fake plan uuid'
         self.uuid = 'test_uuid'
         self.id = 8
@@ -244,10 +247,11 @@ class FakePlan(mock.Mock):
         self.__resource__ = 'plans'
         self.raw_content = {'name': 'faker', 'artifacts': []}
         self.user_id = 'fake user id'
-        self.project_id = 'fake project id'
+        self.project_id = 'fake_project_id'
         self.uuid = 'test_uuid'
         self.id = 8
         self.name = 'faker'
+        self.deploy_keys_uri = None
 
     def as_dict(self):
         return dict(raw_content=self.raw_content,
@@ -269,7 +273,7 @@ class FakeImage(mock.Mock):
         self.__tablename__ = 'image'
         self.__resource__ = 'images'
         self.user_id = 'fake user id'
-        self.project_id = 'fake project id'
+        self.project_id = 'fake_project_id'
         self.uuid = 'test_uuid'
         self.id = 8
         self.name = 'faker'
@@ -343,3 +347,28 @@ class FakeOperation(mock.Mock):
                     documentation=self.documentation,
                     target_resource=self.target_resource,
                     description=self.description)
+
+
+class FakeAttributeDefinition(mock.Mock):
+
+    def __init__(self, **kwargs):
+        super(FakeAttributeDefinition, self).__init__(**kwargs)
+        self.name = 'fake_attribute'
+        self.type = 'attribute_definition'
+
+
+class FakeUserlog(mock.Mock):
+    def __init__(self, **kwargs):
+        super(FakeUserlog, self).__init__(**kwargs)
+        self.assembly_uuid = uuidutils.generate_uuid()
+        self.location = 'fake location'
+        self.strategy = 'local'
+        self.strategy_info = '{}'
+
+
+class FakeParameter(mock.Mock):
+    def __init__(self, **kwargs):
+        super(FakeParameter, self).__init__(**kwargs)
+        self.plan_id = 11
+        self.user_defined_params = {'key': 'ab"cd'}
+        self.sys_defined_params = {}
