@@ -12,24 +12,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import uuid
+
 from solum.objects import registry
 from solum.objects.sqlalchemy import userlog
 from solum.tests import base
 from solum.tests import utils
 
-from oslo_utils import uuidutils
-
 
 class TestUserlog(base.BaseTestCase):
     def setUp(self):
         super(TestUserlog, self).setUp()
         self.db = self.useFixture(utils.Database())
         self.ctx = utils.dummy_context()
-        a_id = uuidutils.generate_uuid()
+        a_id = uuid.uuid4()
 
         self.data = [{'id': 12,
-                      'resource_uuid': '%s' % a_id,
-                      'resource_type': 'app',
+                      'assembly_uuid': '%s' % a_id,
                       'strategy': 'local',
                       'location': '/dev/null',
                       'project_id': self.ctx.tenant,
