@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,8 +19,8 @@ test_solum
 
 Tests for `solum` module.
 """
-from oslo_log import log as logging
 
+from solum.openstack.common import log as logging
 from solum.tests import base
 
 LOG = logging.getLogger(__name__)
