@@ -12,7 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from unittest import mock
+import mock
 
 from solum.tests import base
 from solum.tests import fakes
@@ -33,6 +33,6 @@ class LocalStorageTest(base.BaseTestCase):
                                              assembly, build_id,
                                              "fakestage")
         localstorage.write_userlog_row = mock.MagicMock()
-        localstorage.upload_log()
+        localstorage.upload()
 
         localstorage.write_userlog_row.assert_called_once_with(orig_path)
