@@ -12,8 +12,7 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from oslo_log import log as logging
-
+from solum.openstack.common import log as logging
 import solum.uploaders.common
 
 LOG = logging.getLogger(__name__)
@@ -22,7 +21,7 @@ LOG = logging.getLogger(__name__)
 class LocalStorage(solum.uploaders.common.UploaderBase):
     strategy = "local"
 
-    def upload_log(self):
+    def upload(self):
         LOG.debug("Log already stored locally at %s." %
                   self.original_file_path)
         self.write_userlog_row(self.original_file_path)
