@@ -12,14 +12,13 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from oslo_config import cfg
+from oslo.config import cfg
 
-from solum.common import exception as exc
-from solum.common import solum_swiftclient as swiftclient
+from solum.common import clients
 from solum.openstack.common import log as logging
 import solum.uploaders.common
 
-from swiftclient import exceptions as swiftexp
+from swiftclient import exceptions as swiftexceptions
 
 LOG = logging.getLogger(__name__)
 
@@ -30,29 +29,23 @@ cfg.CONF.import_opt('log_upload_swift_container', 'solum.worker.config',
 class SwiftUpload(solum.uploaders.common.UploaderBase):
     strategy = "swift"
 
-    def _upload(self, container, filename, filepath):
-        swift = swiftclient.SwiftClient(self.context)
-        swift.upload(filepath, container, filename)
-
-    def upload_log(self):
+    def upload(self):
         container = cfg.CONF.worker.log_upload_swift_container
-        filename = "%s-%s/%s-%s.log" % (self.resource.name, self.stage_id,
-                                        self.stage_name, self.stage_id)
+        filename = "%s-%s/%s-%s.log" % (self.assembly.name, self.assembly.uuid,
+                                        self.stage_name, self.build_id)
 
         self.transform_jsonlog()
-        try:
-            LOG.debug("Uploading log to Swift. %s, %s" %
-                      (container, filename))
-            self._upload(container, filename, self.transformed_path)
-        except exc.InvalidObjectSizeError:
-            LOG.exception("Unable to upload logfile: %s to swift. "
-                          "Invalid size." % self.transformed_path)
-            return
-        except swiftexp.ClientException:
-            LOG.exception("Failed to upload logfile: %s to Swift." %
-                          self.transformed_path)
-            return
-        LOG.debug("Logfile uploaded to Swift.")
+        with open(self.transformed_path, 'r') as logfile:
+            try:
+                LOG.debug("Uploading log to Swift. %s, %s" %
+                          (container, filename))
+                swift = clients.OpenStackClients(self.context).swift()
+                swift.put_container(container)
+                swift.put_object(container, filename, logfile)
+            except swiftexceptions.ClientException:
+                LOG.exception("Failed to upload logfile to Swift.")
+                return
+            LOG.debug("Logfile uploaded to Swift.")
 
         swift_info = {
             'container': container,
