@@ -30,6 +30,23 @@ SERVICE_OPTS = [
     cfg.StrOpt('task_log_dir',
                default='/var/log/solum/worker',
                help='The directory containing task log output.'),
+    cfg.StrOpt('proj_dir',
+               default='',
+               help=('The directory containing the project\'s code, '
+                     'especially the contrib directory.')),
+    cfg.StrOpt('log_url_prefix',
+               default='http://localhost/',
+               help='The prefix of test log URL to be sent back'),
+    cfg.StrOpt('log_upload_strategy',
+               default='local',
+               help=('Upload task log to central storage, using modules like '
+                     'swift and local from solum/uploaders.')),
+    cfg.StrOpt('log_upload_swift_container',
+               default='solum-logs',
+               help='The name of the Swift container to upload logs to.'),
+    cfg.StrOpt('param_file_path',
+               default='/tmp/solum',
+               help='The path of param files to save to.'),
 ]
 
 opt_group = cfg.OptGroup(
