@@ -24,13 +24,20 @@ class Handler(object):
         LOG.debug("%s" % message)
 
     def build(self, ctxt, build_id, source_uri, name, base_image_id,
-              source_format, image_format, assembly_id, test_cmd):
-        message = ("Build %s %s %s %s %s %s %s %s" %
-                   (build_id, source_uri, name, base_image_id, source_format,
-                    image_format, assembly_id, test_cmd))
+              source_format, image_format, assembly_id,
+              test_cmd, source_creds_ref=None,
+              artifact_type=None, lp_metadata=None):
+        args = [build_id, source_uri, name, base_image_id, source_format,
+                image_format, assembly_id, test_cmd, source_creds_ref,
+                artifact_type, lp_metadata]
+        message = 'Build ' + ', '.join([str(a) for a in args])
         LOG.debug("%s" % message)
 
-    def unittest(self, ctxt, assembly_id, git_url, test_cmd):
-        message = ("Unittest %s %s %s" %
-                   (assembly_id, git_url, test_cmd))
+    def unittest(self, ctxt, build_id, source_uri, name, base_image_id,
+                 source_format, image_format, assembly_id,
+                 test_cmd, source_creds_ref=None):
+        message = ("Unittest %s %s %s %s %s %s %s %s %s" %
+                   (build_id, source_uri, name, base_image_id, source_format,
+                    image_format, assembly_id,
+                    test_cmd, (source_creds_ref or '')))
         LOG.debug("%s" % message)
